“The Validity and Reliability of an iPhone App for Measuring Running Mechanics”
by Balsalobre-Fernández C, Agopyan H, Morin JB
_Journal of Applied Biomechanics_
© 2016 Human Kinetics, Inc.

# Note. This article will be published in a forthcoming issue of the Journal of Applied Biomechanics . The article appears here in its accepted, peer-reviewed form, as it was provided by the submitting author. It has not been copyedited, proofread, or formatted by the publisher

**Section:** Technical Note

**Article Title:** The Validity and Reliability of an iPhone App for Measuring Running
Mechanics

**Authors:** Carlos Balsalobre-Fernández \[1\], Hovannes Agopyan \[2\], and Jean-Benoit Morin \[2\]

**Affiliations:** \[1\] Department of Sport Sciences, European University of Madrid, Spain.
2Université Côte d'Azur, LAMHESS, Nice, France.

**Journal:** _Journal of Applied Biomechanics_

**Acceptance Date:** November 8, 2016

©2016 Human Kinetics, Inc.

**DOI** : [http://dx.doi.org/10.1123/jab.2016-0104](http://dx.doi.org/10.1123/jab.2016-0104)

“The Validity and Reliability of an iPhone App for Measuring Running Mechanics”
by Balsalobre-Fernández C, Agopyan H, Morin JB
_Journal of Applied Biomechanics_
© 2016 Human Kinetics, Inc.

**The validity and reliability of an iPhone app for measuring running mechanics**

_Carlos Balsalobre-Fernández_ _\[1\]_ _, Hovannes Agopyan_ _\[2\]_ _, Jean-Benoit Morin_ _\[2 \]_

_1 Department of Sport Sciences, European University of Madrid, Spain_

_2 Université Côte d'Azur, LAMHESS, Nice, France_

**Funding:** This research received no specific grant from any funding agency in the public,

commercial, or not-for-profit sectors

**Conflict of Interest Disclosure:** The first author of the article is the creator of the app

mentioned. To guarantee the objectivity of the results, the data from the app were obtained

from two independent observers not related to the app development.

**Correspondence address:**

Department of Sport Sciences, European University of Madrid, Spain.

Address: C/Tajo SN – 28670 Madrid, Spain.

E-mail: <carlos.balsalobre@icloud.com>

**Running title:** iPhone app for measuring running mechanics

“The Validity and Reliability of an iPhone App for Measuring Running Mechanics”
by Balsalobre-Fernández C, Agopyan H, Morin JB
_Journal of Applied Biomechanics_
© 2016 Human Kinetics, Inc.

**Abstract**

The purpose of this investigation was to analyze the validity of an iPhone application

(Runmatic) for measuring running mechanics. To do this, 96 steps from 12 different runs at

speeds ranging from 2.77-5.55 m·s-1 were recorded simultaneously with Runmatic as well as

with an opto-electronic device installed on a motorized treadmill to measure the contact and

aerial time of each step. Additionally, several running mechanics variables were calculated

using the contact and aerial times measured and previously validated equations. Several

statistics were computed to test the validity and reliability of Runmatic in comparison with

the opto-electronic device for the measurement of contact time, aerial time, vertical

oscillation, leg stiffness, maximum relative force, and step frequency. The running mechanics

values obtained with both the app and the opto-electronic device showed a high degree of

correlation (r = 0.94-0.99, p\<0.001). Moreover, there was very close agreement between

instruments as revealed by the ICC (2,1) (ICC = 0.965-0.991). Finally, both Runmatic and the

opto-electronic device showed almost identical reliability levels when measuring each set of

8 steps for every run recorded. In conclusion, Runmatic has been proven to be a highly

reliable tool for measuring the running mechanics studied in this work.

_**Key words:**_ _biomechanics, stride, performance, smartphone_

**Word count: 2289**

“The Validity and Reliability of an iPhone App for Measuring Running Mechanics”
by Balsalobre-Fernández C, Agopyan H, Morin JB
_Journal of Applied Biomechanics_
© 2016 Human Kinetics, Inc.

**Introduction**

There is a large body of research highlighting the importance of monitoring running

mechanics for both performance and injury-prevention purposes \[1–4\] . From the performance

enhancement perspective, the measurement of leg stiffness, vertical oscillation of the center

of mass, and ground contact time is of great interest since these variables seems to play a key

role in running performance \[1,5–7\] and could be used to detect neuromuscular fatigue \[8\] . In the

context of injury prevention, several studies have proposed that stride variables such as leg

stiffness or leg asymmetry when running could be used as indicators for non-contact lower

limb injuries \[3,9,10\] .

The instruments considered the gold standard for measuring running mechanics are

force platforms and instrumented treadmills \[11,12\] . However, the fact that these are unavailable

in many performance centers and clinics (particularly those with fewer resources) may

prevent many coaches and athletes from using them, making running mechanics evaluation

and long-term follow-up impossible. For this reason, many researchers have looked at the

validation of more affordable and practical devices to measure running mechanics, mainly

based on opto-electronic devices and accelerometers \[11,13,14\] . Among these, the _Optojump Next_

is probably the most widely used because of its high degree of validity and reliability

compared with force platforms \[15,16\] . Moreover, contact and aerial times can be used to

calculate leg stiffness, vertical oscillation, step frequency and maximal force of each stride in

a very valid, reliable and accurate way using the mathematical model proposed by Morin et

al. \[17–19\] . Meanwhile, recent studies have analyzed the validity and reliability of less expensive

field-based and easier-to-use accelerometers \[11,13,20\] . However, while highly reliable, their

validity and accuracy in comparison with photoelectric systems are still low for clinical

purposes. For example, a recent study showed that the _Myotest_ device overestimates stride

contact and aerial time by 35-103% compared with the _Optojump next_ system \[13\] especially at

“The Validity and Reliability of an iPhone App for Measuring Running Mechanics”
by Balsalobre-Fernández C, Agopyan H, Morin JB
_Journal of Applied Biomechanics_
© 2016 Human Kinetics, Inc.

low running speeds. Thus, more research is needed to validate new methods for measuring

running mechanics in a practical, affordable but still highly valid and reliable way.

Previous studies have shown the high level of validity and reliability of an iPhone app

for measuring aerial time in jumping activities \[21,22\] . The app calculates aerial time very

accurately thanks to the high-speed camera present on the latest iPhone models, which

precisely detects the contact and take-off of the jump. Thus, we hypothesize that the 240

frames per second camera available on the iPhone 6 and above enables the precise

identification of ground contact and aerial time in running. Therefore, the purpose of the

present study is to analyze the validity and reliability of an iOS application for measuring

contact time, aerial time, and the running mechanics that can be computed from these

variables (i.e., step frequency, vertical oscillation of the center of mass, maximal force and

leg stiffness) during running at different speeds.

**Methods**

_Participants_

Two healthy, non-injured male forefoot striker runners familiar with treadmill running

volunteered to participate. Since the aim of this study was the comparison of several

computations of time (i.e., contact and aerial times) measured with two devices, it was not

necessary to recruit more subjects. Similar analyses with low sample sizes have been used in

previous studies in which the computations are independent from subject’s characteristics \[23\] .

After being informed about experimental procedures, the participants provided written

consent for participating in the study. All the procedures were approved by an institutional

review board and were in agreement with the Declaration of Helsinki.

“The Validity and Reliability of an iPhone App for Measuring Running Mechanics”
by Balsalobre-Fernández C, Agopyan H, Morin JB
_Journal of Applied Biomechanics_
© 2016 Human Kinetics, Inc.

_Instruments_

The app _Runmatic_ was developed ad hoc for this study using Xcode 7.2.1 for Mac OS

X 10.11.3 and the Swift 2.1.1 programming language (Apple Inc., USA). The AVFoundation

and AVKit frameworks (Apple Inc., USA) were used for capturing, importing and

manipulating high-speed videos. The final version of the app (i.e., _Runmatic v.2._ 1) was

installed on an iPhone 6 running iOS 9.2.1 (Apple Inc., USA), which has a recording

frequency of 240 frames per second (fps) at a quality of 720p. The app was designed to use

the 240 fps high-speed recording capabilities of the iPhone in order to accurately detect the

contact and take-off frame of each step on the treadmill and to subsequently calculate the

contact and aerial time of each step. To do this, the app calculates the contact time as the time

between the first frame in which the foot contacts the treadmill and the first frame in which

the foot takes off. The aerial time is calculated as the time between the first frame in which

the foot takes off from the treadmill and the first frame in which the other foot makes contact

with the treadmill. Note that the user indicates to the app which these are by clicking on a

frame during a frame-by-frame visual inspection. Finally, the contact and aerial times

measured with both the app and the opto-electronic device are used to calculate vertical

oscillation, step frequency, relative maximum force, and leg stiffness of each step using the

equations validated in Morin et al. \[17\], on the basis of the following data entered into the app:

subject’s body mass, height, and running speed. Specifically, maximal force (in N) was

𝑡𝑎

𝑡𝑐 \[+ 1)\]\[, with \] _\[m\]_ \[ being the body mass \]

calculated using the following equation: 𝐹𝑚𝑎𝑥= 𝑚𝑔

𝜋

2 \[(\]

of the subject (in kg), _ta_ the aerial time and _tc_ the contact time. Then, leg stiffness (in kN/m)

was calculated as the ratio of the maximal force and the peak vertical displacement of the leg

spring, which was computed from the leg length of the subject ( _L_ = height -in m.- \*0.53), the

running velocity, and the contact time. Finally, results from both instruments were compared.

“The Validity and Reliability of an iPhone App for Measuring Running Mechanics”
by Balsalobre-Fernández C, Agopyan H, Morin JB
_Journal of Applied Biomechanics_
© 2016 Human Kinetics, Inc.

Additionally, the _Optojump Next_ single-meter kit (Microgate, Italy) was used as the

reference device for this study. This instrument, which has a sampling frequency of 1000 Hz

was mounted on a Gymrol S2500 motorized treadmill (HEF Tecmachine, Andrezieux

Boutheon, France). The _Optojump Next_ was connected to a PC running Windows 7 and the

_Optojump Next_ v 1.9 software. Finally, contact and aerial times of 8 consecutive steps were

used to calculate running mechanics using the equations aforementioned, i.e., the same

equations used within _Runmatic_ .

_Procedures_

After completing a standardized warm-up consisting of dynamic lower-limb stretches

and jogging, participants performed 6 different 30 s runs at a zero incline on a Gymrol S2500

motorized treadmill (HEF Tecmachine, Andrezieux-Boutheon, France) at 2.77, 3.33, 3.88,

4.44, 5 and 5.55 m·s \[-1\] in a randomized order. One minute of passive rest was allowed

between each run. Eight steps of each run were analyzed simultaneously with _Runmatic_ and

an _Optojump Next_ opto-electronic device. To record the runs with the app, a researcher lay

prone on the ground, 30 cm from the back of the treadmill and held the iPhone in a vertical

position at the same level as the floor of the treadmill. This setup was used to closely record

the back of the participants’ feet (i.e., in the frontal plane), and was required to make the app

work properly (see Figure 1). It should be noted that, because this procedure is necessary, the

app is designed to be used with a treadmill and not during outdoor runs.

In order to allow participants to stabilize their running pattern at each speed, as well

as synchronize the iPhone app with the _Optojump Next_, the runners were told to drop onto the

treadmill with the right foot. Both systems then started recording at the 12 \[th\] step (i.e., 6 \[th\] left

step). Finally, the app calculated the running mechanics variables using the aforementioned

equations.

“The Validity and Reliability of an iPhone App for Measuring Running Mechanics”
by Balsalobre-Fernández C, Agopyan H, Morin JB
_Journal of Applied Biomechanics_
© 2016 Human Kinetics, Inc.

_Statistical analyses_

Several statistical analyses were performed in order to analyze the validity and

reliability of _Runmatic_ in comparison with the criterion. First, to test the concurrent validity

of _Runmatic_, we used Pearson’s product-moment correlation coefficient, linear regression,

and the standard error of estimate (SEE). Second, to analyze the reliability of the app for the

measurement of contact and aerial time in comparison with the _Optojump Next_, we used the

Intraclass correlation coefficient (ICC-2,1-). Third, to test the reliability of both the app and

the _Optojump Next_ for the measurement of the 8 consecutive steps of each run, Cronbach’s

alpha and the coefficient of variation (CV) were used. Fourth, in order to detect potential

systematic bias, we used the T-test for independent measures and one-way ANOVA that were

complemented with the analysis of the slope of the linear regression line and the SEE. The

level of statistical significance was set at P \< 0.05. All calculations were performed using

IBM SPSS Statistics 22 for Mac (IBM Co., USA).

**Results**

When analyzing the whole dataset (i.e., 96 individual steps measured with both

instruments) Pearson’s product-moment correlation coefficient revealed a very high

relationship between _Runmatic_ and the _Optojump Next_ system ( _Contact time_ : r = 0.99,

p\<0.001, SEE = 0.0056; _Aerial time_ : r = 0.94, p\<0.001, SEE = 0.0048) (see Figure 2).

Moreover, there was a very high agreement between instruments as revealed by the ICC (2,1)

( _Contact time_ : ICC = 0.991, Confidence Interval \[CI\] = 0.987 to 0.994; _Aerial time_ : ICC =

0.965, CI = 0.948 to 0.977).

When proceeding with an independent measures’ T-test, a systematic bias was

observed between _Runmatic_ and the _Optojump Next_ system for the aerial time (mean

difference: +0.006s in _Runmatic_, CI = 0.0017 to 0.01, p \< 0.05) but not for the contact time

“The Validity and Reliability of an iPhone App for Measuring Running Mechanics”
by Balsalobre-Fernández C, Agopyan H, Morin JB
_Journal of Applied Biomechanics_
© 2016 Human Kinetics, Inc.

(mean difference: -0.006s in _Runmatic_, CI = -0.167 to 0.004, p = 0.229). Moreover, when

analyzing the difference between instruments across low (2.77 - 3.33 m/s), moderate (3.88

4.44 m/s) and high (5 – 5.5 m/s) running velocities a statistically significant difference, by

which lower velocities produced higher differences, was observed (p\< 0.001) for both contact

and aerial time. Finally, when analyzing each set of 8 steps to test the reliability of the

instruments for measuring different steps of the same run, both _Runmatic_ and the _Optojump_

_Next_ system had almost identical, very high Cronbach’s alpha and low coefficients of

variation values ( _Contact time: Runmatic_ \[CV = 2.82%, α = 0.996\], _Optojump Next_ \[CV =

2.89%, α = 0.996\]; _Aerial time: Runmatic_ \[CV = 5.2%, α = 0.993\], _Optojump Next_ \[CV =

5.4%, α = 0.969\]).

Finally, there were significant, very high correlations between _Runmatic_ and the

_Optojump Next_ for all the variables computed for the running mechanics analysis (r = 0.94

0.99, CI = 0.91 to 0.99, p\<0.001) (see Table 1).

**Discussion**

The purpose of the present study was to analyze the validity and reliability of a newly

developed iOS application to measure several running mechanics variables. The results

showed very high levels of agreement between _Runmatic_ and the criterion for the

measurement of contact and aerial times, with an ICC higher than 0.96 and a correlation

coefficient ranging from 0.94-0.99 in both variables. Also, the linear regression analyses

showed very high determination coefficients (R \[2\] = 0.89-0.98) and slopes ranging from 0.82

1.03, highlighting the ability of the app to obtain similar values to those measured with the

opto-electronic device. While the contact times measured with _Runmatic_ did not differ

significantly from those obtained with the _Optojump Next,_ a significant difference in aerial

time was observed between the instruments. This could be explained by the smaller values of

“The Validity and Reliability of an iPhone App for Measuring Running Mechanics”
by Balsalobre-Fernández C, Agopyan H, Morin JB
_Journal of Applied Biomechanics_
© 2016 Human Kinetics, Inc.

aerial time compared with contact time (0.113-0.119 _vs._ 0.228-0.234 seconds): the SEE and

the absolute mean difference between instruments ranged from 4-6 milliseconds for both

variables, but that value is proportionally higher for the aerial time making the difference

more noticeable in the T-test. Thus, despite being statistically significant for aerial time,

overall the magnitude of difference between the instruments was very low. Moreover, when

analyzing the difference between instruments across all the running velocities, a significant

difference was observed between low (2.77 - 3.33 m/s), moderate (3.88 - 4.44 m/s) and high

(5 – 5.5 m/s) velocities, where lower velocities produced greater differences (mean difference

for contact time: low velocities = 0.01 s, moderate velocities = 0.007 s, high velocities =

0.002 s; mean difference for aerial time: low velocities = -0.01 s, moderate velocities =

0.006 s, high velocities = -0.001 s). It would therefore be interesting to test if these

differences are still small when running velocities other than those covered in this work are

studied.

However, since both instruments demonstrated almost identical levels of reliability

when measuring each set of 8 steps for the different runs and running velocities, the

aforementioned differences should be consistent and therefore, the app could be used to track

changes in performance over time. These results are in line with the study by Girard et al. \[24\]

in which high levels of intra- and inter-day reliability were observed in the computation of

mechanical running parameters using the spring-mass model described in Morin et al. and an

instrumented treadmill \[17\] . This could therefore be a useful technique for coaches or therapists

who wish to monitor running mechanics over time without advanced instruments.

Vertical oscillation, leg stiffness, maximum relative force, and step frequency values

also showed a very high level of correlation (r = 0.94-0.97) and small absolute mean

differences (2.2-6.5%) between the two instruments. Other studies have also aimed to test

more affordable devices than force platforms or opto-electronic devices. For example, while

“The Validity and Reliability of an iPhone App for Measuring Running Mechanics”
by Balsalobre-Fernández C, Agopyan H, Morin JB
_Journal of Applied Biomechanics_
© 2016 Human Kinetics, Inc.

the reliability of _Myotest_ when measuring contact time, aerial time and step frequency was

high to very high (ICC = 0.835-0.999), its validity was not acceptable, with absolute mean

bias up to 103 % between devices \[13\] . In conclusion, the app analyzed in the present study is

both a valid and reliable tool for measuring contact time, aerial time, vertical oscillation, leg

stiffness, maximum relative force and step frequency.

**Acknowledgements**

The authors want to thank the participants and the observers for their involvement in the

present study.

“The Validity and Reliability of an iPhone App for Measuring Running Mechanics”
by Balsalobre-Fernández C, Agopyan H, Morin JB
_Journal of Applied Biomechanics_
© 2016 Human Kinetics, Inc.

**References**

1. Moore IS. Is There an Economical Running Technique? A Review of Modifiable
   Biomechanical Factors Affecting Running Economy. _Sport Med_ . 2016.
   doi:10.1007/s40279-016-0474-4.

1. Santos-Concejero J, Tam N, Granados C, et al. Stride angle as a novel indicator of
   running economy in well-trained runners. _J Strength Cond Res_ . 2014;28(7):18891895. doi:10.1519/jsc.0000000000000325.

1. Butler RJ, Crowell HP, Davis IM. Lower extremity stiffness: Implications for
   performance and injury. _Clin Biomech_ . 2003;18(6):511-517. doi:10.1016/S02680033(03)00071-8.

1. Pappas P, Paradisis G, Vagenas G. Leg and vertical stiffness (a)symmetry between
   dominant and non-dominant legs in young male runners. _Hum Mov Sci_ . 2015;40:273283. doi:10.1016/j.humov.2015.01.005.

1. Barnes KR, Kilding AE. Running economy: measurement, norms, and determining
   factors. _Sport Med - Open_ . 2015;1(1):8. doi:10.1186/s40798-015-0007-y.

1. Santos-Concejero J, Olivan J, Mate-Munoz JL, et al. Gait Cycle Characteristics and
   Running Economy in Elite Eritrean and European Runners. _Int J Sports Physiol_
   _Perform_ . 2014. doi:10.1123/ijspp.2014-0179.

1. Chapman RF, Laymon AS, Wilhite DP, McKenzie JM, Tanner DA, Stager JM.
   Ground Contact Time as an Indicator of Metabolic Cost in Elite Distance Runners.

_Med Sci Sport Exerc_ . 2012;44(5):917-925.

8. Buchheit M, Gray A, Morin J-B. Assessing Stride Variables and Vertical Stiffness
   with GPS-Embedded Accelerometers: Preliminary Insights for the Monitoring of
   Neuromuscular Fatigue on the Field. _J Sport Sci Med_ . 2015;14:698-701.

1. Hewit J, Cronin J, Hume P. Multidirectional Leg Asymmetry Assessment in Sport.
   _Strength Cond J_ . 2012;34(1):82-86. doi:10.1519/SSC.0b013e31823e83db.

1. Fousekis K, Tsepis E, Poulmedis P, Athanasopoulos S, Vagenas G. Intrinsic risk
   factors of non-contact quadriceps and hamstring strains in soccer: a prospective study
   of 100 professional players. _Br J Sports Med_ . 2011;45(9):709-714.
   doi:10.1136/bjsm.2010.077560.

1. Watari R, Hettinga B, Osis S, Ferber R. Validation of a Torso-Mounted
   Accelerometer for Measures of Vertical Oscillation and Ground Contact Time During
   Treadmill Running. _J Appl Biomech_ . 2015;11(1):86-95. doi:10.1123/jab.2015-0200.

1. Bundle MW, Powell MO, Ryan LJ. Design and testing of a high-speed treadmill to
   measure ground reaction forces at the limit of human gait. _Med Eng Phys_ .
   2015;37(9):892-897. doi:10.1016/j.medengphy.2015.04.009.

1. Gindre C, Lussiana T, Hebert-Losier K, Morin J-B. Reliability and validity of the
   Myotest® for measuring running stride kinematics. _J Sports Sci_ . 2015:1-7.
   doi:10.1080/02640414.2015.1068436.

“The Validity and Reliability of an iPhone App for Measuring Running Mechanics”
by Balsalobre-Fernández C, Agopyan H, Morin JB
_Journal of Applied Biomechanics_
© 2016 Human Kinetics, Inc.

14. Ammann R, Taube W, Wyss T. Accuracy of PARTwear inertial sensor and Optojump
    optical measurement system for measuring ground contact time during running. _J_
    _Strength Cond Res_ . 2015:1. doi:10.1519/JSC.0000000000001299.

01. Glatthorn JF, Gouge S, Nussbaumer S, Stauffacher S, Impellizzeri FM, Maffiuletti
    NA. Validity and reliability of Optojump photoelectric cells for estimating vertical
    jump height. _J Strength Cond Res_ . 2011;25(2):556-560.

01. Ruggiero L, Dewhurst S, Bampouras TM. Validity and Reliability of Two FieldBased Leg Stiffness Devices: Implications for Practical Use. _J Appl Biomech_ . 2016.
    doi:10.1123/jab.2015-0297.

01. Morin JB, Dalleau G, Kyröläinen H, Jeannin T, Belli A. A simple method for
    measuring stiffness during running. _J Appl Biomech_ . 2005;21(2):167-180.
    doi:10.1519/JSC.0b013e318260edad.

01. Coleman DR, Cannavan D, Horne S, Blazevich AJ. Leg stiffness in human running:
    Comparison of estimates derived from previously published models to direct
    kinematic-kinetic measures. _J Biomech_ . 2012;45(11):1987-1991.
    doi:10.1016/j.jbiomech.2012.05.010.

01. Pappas P, Paradisis G, Tsolakis C, Smirniotou A, Morin J-B. Reliabilities of leg and
    vertical stiffness during treadmill running. _Sports Biomech_ . 2014;13(4):391-399.
    doi:10.1080/14763141.2014.981853.

01. Gouttebarge V, Wolfard R, Griek N, de Ruiter CJ, Boschman JS, van Dieën JH.
    Reproducibility and validity of the myotest for measuring step frequency and ground
    contact time in recreational runners. _J Hum Kinet_ . 2015;45:19-26. doi:10.1515/hukin2015-0003.

01. Balsalobre-Fernández C, Glaister M, Lockey RA. The validity and reliability of an
    iPhone app for measuring vertical jump performance. _J Sports Sci_ . 2015;33(15):15741579. doi:10.1080/02640414.2014.996184.

01. Gallardo-Fuentes F, Gallardo-Fuentes J, Ramírez-Campillo R, et al. Inter And IntraSession Reliability And Validity Of The My Jump App For Measuring Different
    Jump Actions In Trained Male And Female Athletes. _J Strength Cond Res_ . 2015.
    doi:10.1519/JSC.0000000000001304.

01. Morin J-B, Belli A. A simple method for measurement of maximal downstroke power
    on friction-loaded cycle ergometer. _J Biomech_ . 2004;37(1):141-145.
    doi:10.1016/S0021-9290(03)00253-7.

01. Girard O, Brocherie F, Morin JB, Millet GP. Intra- and Inter-Session Reliability of
    Running Mechanics During Treadmill Sprints. _Int J Sports Physiol Perform_ . 2015.
    doi:10.1123/ijspp.2015-0145.

“The Validity and Reliability of an iPhone App for Measuring Running Mechanics”
by Balsalobre-Fernández C, Agopyan H, Morin JB
_Journal of Applied Biomechanics_
© 2016 Human Kinetics, Inc.

## Figure 1 — User interface of Runmatic, showing how a properly recorded video should

look.

“The Validity and Reliability of an iPhone App for Measuring Running Mechanics”
by Balsalobre-Fernández C, Agopyan H, Morin JB
_Journal of Applied Biomechanics_
© 2016 Human Kinetics, Inc.

## —

**Figure 2** Linear relationship between _Runmatic_ app and the opto-electronic device for the
measurement of (A) contact time and (B) aerial time at speeds ranging 2.77-5.55 m·s \[-1\] .

“The Validity and Reliability of an iPhone App for Measuring Running Mechanics”
by Balsalobre-Fernández C, Agopyan H, Morin JB
_Journal of Applied Biomechanics_
© 2016 Human Kinetics, Inc.

**Table 1.** Mean values  SD of the running mechanics computed using _Runmatic_ and the
opto-electronic device, mean absolute bias between instruments and Pearson’s productmoment correlation coefficient

_Runmatic_ _Optojump_ _Absolute bias_ _Pearson’s_ _Slope of the linear_

_Standard_

_error of_

_estimate_

_Absolute bias_

_Pearson’s_

_Slope of the linear_

_regression line_

_correlation_

_coefficient (r)_

_Next_

_(%)_

_Contact time (s)_ 0.228  0.348 0.234  0.383 3.0 0.99 (0.98-0.99)\*\* 0.9 0.0056

_Aerial time (s)_ 0.119  0.144 0.113  0.165 5.9\* 0.94 (0.91-0.96)\*\* 0.82 0.0048

_Vertical_

_oscillation (m)_

0.059  0.008 0.059  0.009 2.2 0.97 (0.96-0.98)\*\* 0.93 0.0019

_Fmax (BW)_ 2.412  0.206 2.362  0.229 2.8 0.97 (0.96-0.98)\*\* 0.88 0.0473

_Leg stiffness_

_(kN/m)_

9.443  1.832 8.909  1.678 6.5\* 0.94 (0.92-0.96)\*\* 1.03 0.6259

- Significant difference as revealed by the T-test for independent measures, p\<0.05

\*\*p\<0.001
